import {themes as prismThemes} from 'prism-react-renderer';
import type {Config} from '@docusaurus/types';
import type * as Preset from '@docusaurus/preset-classic';

const config: Config = {
  title: 'Libre Wedding Planner',
  tagline: 'Free and open-source wedding planning software to organize your wedding',
  favicon: 'img/favicon.ico',

  url: 'https://libreweddingplanner.org',
  baseUrl: '/',

  organizationName: 'bustikiller',
  projectName: 'wedding-planner-website',

  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',

  i18n: {
    defaultLocale: 'en',
    locales: ['en'],
  },

  presets: [
    [
      'classic',
      {
        docs: {
          sidebarPath: './sidebars.ts',
          editUrl:
            'https://gitea.bustikiller.com/bustikiller/wedding-planner-website/',
        },
        blog: {
          showReadingTime: true,
          feedOptions: {
            type: ['rss', 'atom'],
            xslt: true,
          },
          editUrl:
            'https://gitea.bustikiller.com/bustikiller/wedding-planner-website/',
          onInlineTags: 'warn',
          onInlineAuthors: 'warn',
          onUntruncatedBlogPosts: 'warn',
        },
        theme: {
          customCss: './src/css/custom.css',
        },
      } satisfies Preset.Options,
    ],
  ],

  themeConfig: {
    image: 'img/docusaurus-social-card.jpg',
    navbar: {
      title: 'Libre Wedding Planner',
      logo: {
        alt: 'Libre Wedding Planner Logo',
        src: 'img/logo.png',
      },
      items: [
        {
          type: 'docSidebar',
          sidebarId: 'tutorialSidebar',
          position: 'left',
          label: 'Tutorial',
        },
        {to: '/blog', label: 'Blog', position: 'left'},
      ],
    },
    footer: {
      style: 'dark',
      links: [
        {
          title: 'Docs',
          items: [
            {
              label: 'Tutorial',
              to: '/docs/intro',
            },
          ],
        },
        {
          title: 'Source code',
          items: [
            {
              label: 'Backend',
              href: 'https://gitea.bustikiller.com/bustikiller/wedding-planner/',
            },
            {
              label: 'Frontend',
              href: 'https://gitea.bustikiller.com/bustikiller/wedding-planner-frontend/',
            },
            {
              label: 'Website',
              href: 'https://gitea.bustikiller.com/bustikiller/wedding-planner-website/',
            },
          ],
        },
        {
          title: 'More',
          items: [
            {
              label: 'Blog',
              to: '/blog',
            }
          ],
        },
      ],
      copyright: `Copyright © ${new Date().getFullYear()} Manuel Bustillo. Built with Docusaurus.`,
    },
    prism: {
      theme: prismThemes.github,
      darkTheme: prismThemes.dracula,
    },
  } satisfies Preset.ThemeConfig,
};

export default config;
